# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

import grpc

from . import invoice_pb2 as invoice_dot_grpc_dot_invoice__pb2


class CreateInvoiceControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel=None):
        """Constructor.

        Args:
            self.channel: A grpc.Channel.
        """
        self.channel = channel
        self.ready()

    def ready(self):
        if self.channel is not None:
            self.Create = self.channel.unary_unary(
                "/config.invoice.CreateInvoiceController/Create",
                request_serializer=invoice_dot_grpc_dot_invoice__pb2.CreateInvoiceRequest.SerializeToString,
                response_deserializer=invoice_dot_grpc_dot_invoice__pb2.CreateInvoiceResponse.FromString,
            )


class CreateInvoiceControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_CreateInvoiceControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Create": grpc.unary_unary_rpc_method_handler(
            servicer.Create,
            request_deserializer=invoice_dot_grpc_dot_invoice__pb2.CreateInvoiceRequest.FromString,
            response_serializer=invoice_dot_grpc_dot_invoice__pb2.CreateInvoiceResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "config.invoice.CreateInvoiceController", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class CreateInvoiceController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.invoice.CreateInvoiceController/Create",
            invoice_dot_grpc_dot_invoice__pb2.CreateInvoiceRequest.SerializeToString,
            invoice_dot_grpc_dot_invoice__pb2.CreateInvoiceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class InquiryInvoiceControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel=None):
        """Constructor.

        Args:
            self.channel: A grpc.Channel.
        """
        self.channel = channel
        self.ready()

    def ready(self):
        if self.channel is not None:
            self.Retrieve = self.channel.unary_unary(
                "/config.invoice.InquiryInvoiceController/Retrieve",
                request_serializer=invoice_dot_grpc_dot_invoice__pb2.InquiryInvoiceRetrieveRequest.SerializeToString,
                response_deserializer=invoice_dot_grpc_dot_invoice__pb2.InquiryInvoiceResponse.FromString,
            )


class InquiryInvoiceControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_InquiryInvoiceControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Retrieve": grpc.unary_unary_rpc_method_handler(
            servicer.Retrieve,
            request_deserializer=invoice_dot_grpc_dot_invoice__pb2.InquiryInvoiceRetrieveRequest.FromString,
            response_serializer=invoice_dot_grpc_dot_invoice__pb2.InquiryInvoiceResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "config.invoice.InquiryInvoiceController", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class InquiryInvoiceController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Retrieve(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.invoice.InquiryInvoiceController/Retrieve",
            invoice_dot_grpc_dot_invoice__pb2.InquiryInvoiceRetrieveRequest.SerializeToString,
            invoice_dot_grpc_dot_invoice__pb2.InquiryInvoiceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class InquiryPaymentControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel=None):
        """Constructor.

        Args:
            self.channel: A grpc.Channel.
        """
        self.channel = channel
        self.ready()

    def ready(self):
        if self.channel is not None:
            self.Retrieve = self.channel.unary_unary(
                "/config.invoice.InquiryPaymentController/Retrieve",
                request_serializer=invoice_dot_grpc_dot_invoice__pb2.InquiryPaymentRetrieveRequest.SerializeToString,
                response_deserializer=invoice_dot_grpc_dot_invoice__pb2.InquiryPaymentResponse.FromString,
            )


class InquiryPaymentControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Retrieve(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_InquiryPaymentControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Retrieve": grpc.unary_unary_rpc_method_handler(
            servicer.Retrieve,
            request_deserializer=invoice_dot_grpc_dot_invoice__pb2.InquiryPaymentRetrieveRequest.FromString,
            response_serializer=invoice_dot_grpc_dot_invoice__pb2.InquiryPaymentResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "config.invoice.InquiryPaymentController", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class InquiryPaymentController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Retrieve(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.invoice.InquiryPaymentController/Retrieve",
            invoice_dot_grpc_dot_invoice__pb2.InquiryPaymentRetrieveRequest.SerializeToString,
            invoice_dot_grpc_dot_invoice__pb2.InquiryPaymentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class PaymentInvoiceControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel=None):
        """Constructor.

        Args:
            self.channel: A grpc.Channel.
        """
        self.channel = channel
        self.ready()

    def ready(self):
        if self.channel is not None:
            self.PaymentRequest = self.channel.unary_unary(
                "/config.invoice.PaymentInvoiceController/PaymentRequest",
                request_serializer=invoice_dot_grpc_dot_invoice__pb2.PaymentRequestRequest.SerializeToString,
                response_deserializer=invoice_dot_grpc_dot_invoice__pb2.PaymentRequestResponse.FromString,
            )
            self.VerifyPayment = self.channel.unary_unary(
                "/config.invoice.PaymentInvoiceController/VerifyPayment",
                request_serializer=invoice_dot_grpc_dot_invoice__pb2.VerifyPaymentRequest.SerializeToString,
                response_deserializer=invoice_dot_grpc_dot_invoice__pb2.VerifyPaymentResponse.FromString,
            )


class PaymentInvoiceControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PaymentRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def VerifyPayment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_PaymentInvoiceControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "PaymentRequest": grpc.unary_unary_rpc_method_handler(
            servicer.PaymentRequest,
            request_deserializer=invoice_dot_grpc_dot_invoice__pb2.PaymentRequestRequest.FromString,
            response_serializer=invoice_dot_grpc_dot_invoice__pb2.PaymentRequestResponse.SerializeToString,
        ),
        "VerifyPayment": grpc.unary_unary_rpc_method_handler(
            servicer.VerifyPayment,
            request_deserializer=invoice_dot_grpc_dot_invoice__pb2.VerifyPaymentRequest.FromString,
            response_serializer=invoice_dot_grpc_dot_invoice__pb2.VerifyPaymentResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "config.invoice.PaymentInvoiceController", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class PaymentInvoiceController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PaymentRequest(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.invoice.PaymentInvoiceController/PaymentRequest",
            invoice_dot_grpc_dot_invoice__pb2.PaymentRequestRequest.SerializeToString,
            invoice_dot_grpc_dot_invoice__pb2.PaymentRequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def VerifyPayment(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.invoice.PaymentInvoiceController/VerifyPayment",
            invoice_dot_grpc_dot_invoice__pb2.VerifyPaymentRequest.SerializeToString,
            invoice_dot_grpc_dot_invoice__pb2.VerifyPaymentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class UserListInvoiceControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel=None):
        """Constructor.

        Args:
            self.channel: A grpc.Channel.
        """
        self.channel = channel
        self.ready()

    def ready(self):
        if self.channel is not None:
            self.UserRelatedList = self.channel.unary_unary(
                "/config.invoice.UserListInvoiceController/UserRelatedList",
                request_serializer=invoice_dot_grpc_dot_invoice__pb2.UserListInvoiceRequest.SerializeToString,
                response_deserializer=invoice_dot_grpc_dot_invoice__pb2.UserListInvoiceResponse.FromString,
            )


class UserListInvoiceControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UserRelatedList(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_UserListInvoiceControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "UserRelatedList": grpc.unary_unary_rpc_method_handler(
            servicer.UserRelatedList,
            request_deserializer=invoice_dot_grpc_dot_invoice__pb2.UserListInvoiceRequest.FromString,
            response_serializer=invoice_dot_grpc_dot_invoice__pb2.UserListInvoiceResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "config.invoice.UserListInvoiceController", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class UserListInvoiceController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UserRelatedList(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/config.invoice.UserListInvoiceController/UserRelatedList",
            invoice_dot_grpc_dot_invoice__pb2.UserListInvoiceRequest.SerializeToString,
            invoice_dot_grpc_dot_invoice__pb2.UserListInvoiceResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
