# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: invoice/grpc/invoice.proto
# Protobuf Python Version: 4.25.1
# pylint: skip-file
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1ainvoice/grpc/invoice.proto\x12\x0e\x63onfig.invoice\x1a\x1cgoogle/protobuf/struct.proto"\x93\x02\n\x14\x43reateInvoiceRequest\x12\x18\n\x10owner_identifier\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x05\x12\x30\n\nextra_data\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x88\x01\x01\x12\x1e\n\x11\x62\x61sket_identifier\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0f\x64iscount_amount\x18\x06 \x01(\x05H\x02\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x07 \x01(\tH\x03\x88\x01\x01\x42\r\n\x0b_extra_dataB\x14\n\x12_basket_identifierB\x12\n\x10_discount_amountB\x0e\n\x0c_description"]\n\x15\x43reateInvoiceResponse\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0c\n\x04\x63ode\x18\x04 \x01(\t\x12%\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32\x17.google.protobuf.Struct"^\n\x16InquiryInvoiceResponse\x12\x0f\n\x07message\x18\x07 \x01(\t\x12\x0c\n\x04\x63ode\x18\x08 \x01(\t\x12%\n\x04\x64\x61ta\x18\t \x03(\x0b\x32\x17.google.protobuf.Struct"6\n\x1dInquiryInvoiceRetrieveRequest\x12\x15\n\rtracking_code\x18\x01 \x01(\t"^\n\x16InquiryPaymentResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"6\n\x1dInquiryPaymentRetrieveRequest\x12\x15\n\rtracking_code\x18\x01 \x01(\t"c\n\x15PaymentRequestRequest\x12\x18\n\x0b\x64\x65scription\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07gateway\x18\x02 \x01(\t\x12\x0f\n\x07invoice\x18\x03 \x01(\tB\x0e\n\x0c_description"^\n\x16PaymentRequestResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"2\n\x16UserListInvoiceRequest\x12\x18\n\x10owner_identifier\x18\x01 \x01(\t"_\n\x17UserListInvoiceResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct"J\n\x14VerifyPaymentRequest\x12\x16\n\x0egateway_status\x18\x01 \x01(\t\x12\x1a\n\x12payment_identifier\x18\x02 \x01(\t"]\n\x15VerifyPaymentResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x17.google.protobuf.Struct2r\n\x17\x43reateInvoiceController\x12W\n\x06\x43reate\x12$.config.invoice.CreateInvoiceRequest\x1a%.config.invoice.CreateInvoiceResponse"\x00\x32\x7f\n\x18InquiryInvoiceController\x12\x63\n\x08Retrieve\x12-.config.invoice.InquiryInvoiceRetrieveRequest\x1a&.config.invoice.InquiryInvoiceResponse"\x00\x32\x7f\n\x18InquiryPaymentController\x12\x63\n\x08Retrieve\x12-.config.invoice.InquiryPaymentRetrieveRequest\x1a&.config.invoice.InquiryPaymentResponse"\x00\x32\xdd\x01\n\x18PaymentInvoiceController\x12\x61\n\x0ePaymentRequest\x12%.config.invoice.PaymentRequestRequest\x1a&.config.invoice.PaymentRequestResponse"\x00\x12^\n\rVerifyPayment\x12$.config.invoice.VerifyPaymentRequest\x1a%.config.invoice.VerifyPaymentResponse"\x00\x32\x81\x01\n\x19UserListInvoiceController\x12\x64\n\x0fUserRelatedList\x12&.config.invoice.UserListInvoiceRequest\x1a\'.config.invoice.UserListInvoiceResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "invoice.grpc.invoice_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_CREATEINVOICEREQUEST"]._serialized_start = 77
    _globals["_CREATEINVOICEREQUEST"]._serialized_end = 352
    _globals["_CREATEINVOICERESPONSE"]._serialized_start = 354
    _globals["_CREATEINVOICERESPONSE"]._serialized_end = 447
    _globals["_INQUIRYINVOICERESPONSE"]._serialized_start = 449
    _globals["_INQUIRYINVOICERESPONSE"]._serialized_end = 543
    _globals["_INQUIRYINVOICERETRIEVEREQUEST"]._serialized_start = 545
    _globals["_INQUIRYINVOICERETRIEVEREQUEST"]._serialized_end = 599
    _globals["_INQUIRYPAYMENTRESPONSE"]._serialized_start = 601
    _globals["_INQUIRYPAYMENTRESPONSE"]._serialized_end = 695
    _globals["_INQUIRYPAYMENTRETRIEVEREQUEST"]._serialized_start = 697
    _globals["_INQUIRYPAYMENTRETRIEVEREQUEST"]._serialized_end = 751
    _globals["_PAYMENTREQUESTREQUEST"]._serialized_start = 753
    _globals["_PAYMENTREQUESTREQUEST"]._serialized_end = 852
    _globals["_PAYMENTREQUESTRESPONSE"]._serialized_start = 854
    _globals["_PAYMENTREQUESTRESPONSE"]._serialized_end = 948
    _globals["_USERLISTINVOICEREQUEST"]._serialized_start = 950
    _globals["_USERLISTINVOICEREQUEST"]._serialized_end = 1000
    _globals["_USERLISTINVOICERESPONSE"]._serialized_start = 1002
    _globals["_USERLISTINVOICERESPONSE"]._serialized_end = 1097
    _globals["_VERIFYPAYMENTREQUEST"]._serialized_start = 1099
    _globals["_VERIFYPAYMENTREQUEST"]._serialized_end = 1173
    _globals["_VERIFYPAYMENTRESPONSE"]._serialized_start = 1175
    _globals["_VERIFYPAYMENTRESPONSE"]._serialized_end = 1268
    _globals["_CREATEINVOICECONTROLLER"]._serialized_start = 1270
    _globals["_CREATEINVOICECONTROLLER"]._serialized_end = 1384
    _globals["_INQUIRYINVOICECONTROLLER"]._serialized_start = 1386
    _globals["_INQUIRYINVOICECONTROLLER"]._serialized_end = 1513
    _globals["_INQUIRYPAYMENTCONTROLLER"]._serialized_start = 1515
    _globals["_INQUIRYPAYMENTCONTROLLER"]._serialized_end = 1642
    _globals["_PAYMENTINVOICECONTROLLER"]._serialized_start = 1645
    _globals["_PAYMENTINVOICECONTROLLER"]._serialized_end = 1866
    _globals["_USERLISTINVOICECONTROLLER"]._serialized_start = 1869
    _globals["_USERLISTINVOICECONTROLLER"]._serialized_end = 1998
# @@protoc_insertion_point(module_scope)
